diff ui/mainwindow.h @ 1373:00fcb9c4d16b

(issue179) Handle SW verify failures and try to redownload the update
author Andre Heinecke <andre.heinecke@intevation.de>
date Mon, 24 Nov 2014 16:46:08 +0100
parents 23df332b2a4c
children
line wrap: on
line diff
--- a/ui/mainwindow.h	Mon Nov 24 15:49:18 2014 +0100
+++ b/ui/mainwindow.h	Mon Nov 24 16:46:08 2014 +0100
@@ -120,9 +120,10 @@
     void iconActivated(QSystemTrayIcon::ActivationReason reason);
     /** @brief Check if new updates are available.
      *
      * @param[in] downloadSW wether or not new software should be downloaded.
      */
-    void checkUpdates(bool downloadSW = false);
+    void checkUpdates();
     /**@brief parse a new certificate list and update the UI*/
     void handleNewList(const QString& fileName, const QDateTime& modDate);
     /**@brief handle a Software update, update state and inform the user */
@@ -294,6 +295,16 @@
      **/
     void handleLTE(LongTimeErrors lte, bool reset = false);
 
+    /** @brief schedule an update check retry or close the application.
+     *
+     * An update check retry is scheduled base on getNextUpdateInterval.
+     * If getNextUpdateInterval returns a negative value the application
+     * is closed if the parameter close is true.
+     *
+     * This function also increases the failed connection count.
+     */
+    void scheduleFailureRetryOrClose(bool close);
+
     /** @brief note a verify error in the settings and show a message
      *
      * Saves a software verify error in the settings and notifies the
@@ -386,6 +397,7 @@
     bool mManualDetailsShown;
     int mFailedConnections;
     QDateTime mSigDt;
+    bool mDownloadSWAccepted;
 };
 
 #endif // MAINWINDOW_H
@@ -120,9 +120,10 @@
     /** @brief Check if new updates are available.
      *
-     * @param[in] downloadSW wether or not new software should be downloaded.
+     * Wether the software should be downloaded or not is determined by
+     * the mDownloadSWAccepted value.
      */

http://wald.intevation.org/projects/trustbridge/